#!/usr/bin/env python

from ytscraper import app

if __name__ == "__main__":
    app.run()
